Page 79 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 79

Home

    revolutionary forces and formed military encampments of
    private troops up and down the Mississippi River, which
    was then the western boundary of the United States. His
    plan was to start an insurrection and break away that
    portion of the country. Burr's activities came at about the
    time of the Louisiana Purchase which means that he was

    Burr was eventually arrested and put on trial.
    The Theistical Society was another subversive group
    that operated out of New York. It's existence was

    r4 x«rT 1 a

    discovered and publicized by John Wood, a Scottish
    cartographer and teacher. The head of the organization
    was Elihu Palmer a blind minister. Palmer was a deist

    who denied the existence of a personal God. William H.
    Mcllhany said this about the Society:

    Like its Bavarian origin, the Society promoted the
    distribution of publications attacking all religious belief
    and any form of government other than democracy.
    Most notable among these, in addition to Paine's Age of
    Reason, was Palmer's own Principles of Nature.”

    Theistical Society members advocated using a
    strategy of "patient gradualism" to accomplish then-
    goals. They also sought to finance and lead their own
    opposition in waging a public ideological crusade against
    them. This was done to give the Society the appearance
    of nothing more than the promoter of an idealistic
    campaign, thus obscuring their secret subversive
    program. This program, of leading your opposition, has

    74

    The Secret Side of History

    making a grab for an immense amount of territory. Aaron